"""
Creates a test case class for use with the unittest library that is built into Python.
"""

from heaserver.service.testcase.microservicetestcase import get_test_case_cls_default
from heaserver.keychain import service
from heaobject.user import NONE_USER
from heaserver.service.testcase.expectedvalues import Action

credentials_db_store = {
    service.MONGODB_CREDENTIALS_COLLECTION: [{
        'id': '666f6f2d6261722d71757578',
        'instance_id': 'heaobject.keychain.Credentials^666f6f2d6261722d71757578',
        'created': None,
        'derived_by': None,
        'derived_from': [],
        'description': None,
        'display_name': 'Reximus',
        'invites': [],
        'modified': None,
        'name': 'reximus',
        'owner': NONE_USER,
        'shares': [],
        'source': None,
        'source_detail': None,
        'type': 'heaobject.keychain.Credentials',
        'created': None,
        'account': None,
        'where': None,
        'password': None,
        'type_display_name': 'Credentials',
        'role': None,
        'expiration': None,
        'lifespan_class': 'LONG_LIVED',
        'lifespan': None,
        'maximum_duration': None,
        'time_to_expire': None
    },
        {
            'id': '0123456789ab0123456789ab',
            'instance_id': 'heaobject.keychain.Credentials^0123456789ab0123456789ab',
            'created': None,
            'derived_by': None,
            'derived_from': [],
            'description': None,
            'display_name': 'Luximus',
            'invites': [],
            'modified': None,
            'name': 'luximus',
            'owner': NONE_USER,
            'shares': [],
            'source': None,
            'source_detail': None,
            'type': 'heaobject.keychain.Credentials',
            'account': None,
            'created': None,
            'where': None,
            'password': None,
            'type_display_name': 'Credentials',
            'role': None,
            'expiration': None,
            'lifespan_class': 'LONG_LIVED',
            'lifespan': None,
            'maximum_duration': None,
            'time_to_expire': None
        }]}

CredentialsTestCase = get_test_case_cls_default(coll=service.MONGODB_CREDENTIALS_COLLECTION,
                                     wstl_package=service.__package__,
                                     href='http://localhost:8080/credentials/',
                                     fixtures=credentials_db_store,
                                     get_actions=[Action(name='heaserver-keychain-credentials-get-properties',
                                                             rel=['hea-context-menu', 'hea-properties']),
                                                  Action(name='heaserver-keychain-credentials-get-self',
                                                             url='http://localhost:8080/credentials/{id}',
                                                             rel=['self'])
                                                  ],
                                     get_all_actions=[Action(name='heaserver-keychain-credentials-get-properties',
                                                             rel=['hea-context-menu', 'hea-properties']),
                                                      Action(name='heaserver-keychain-credentials-get-self',
                                                                 url='http://localhost:8080/credentials/{id}',
                                                                 rel=['self'])]
                                     )


aws_credentials_db_store = {
    service.MONGODB_CREDENTIALS_COLLECTION: [{
        'id': '666f6f2d6261722d71757578',
        'instance_id': 'heaobject.keychain.AWSCredentials^666f6f2d6261722d71757578',
        'created': None,
        'derived_by': None,
        'derived_from': [],
        'description': None,
        'display_name': 'Reximus',
        'invites': [],
        'modified': None,
        'name': 'reximus',
        'owner': NONE_USER,
        'shares': [],
        'source': None,
        'source_detail': None,
        'type': 'heaobject.keychain.AWSCredentials',
        'created': None,
        'account': None,
        'where': None,
        'password': None,
        'type_display_name': 'AWS Credentials',
        'role': None,
        'expiration': None,
        'lifespan_class': 'LONG_LIVED',
        'lifespan': None,
        'maximum_duration': None,
        'time_to_expire': None,
        'temporary': False,
        'account_id': None,
        'aws_role_name': None,
        'managed': False,
        'role_arn': None,
        'session_token': None,
        'state': 'DEFAULT',
        'for_presigned_url': False
    },
        {
            'id': '0123456789ab0123456789ab',
            'instance_id': 'heaobject.keychain.AWSCredentials^0123456789ab0123456789ab',
            'created': None,
            'derived_by': None,
            'derived_from': [],
            'description': None,
            'display_name': 'Luximus',
            'invites': [],
            'modified': None,
            'name': 'luximus',
            'owner': NONE_USER,
            'shares': [],
            'source': None,
            'source_detail': None,
            'type': 'heaobject.keychain.AWSCredentials',
            'account': None,
            'created': None,
            'where': None,
            'password': None,
            'type_display_name': 'AWS Credentials',
            'role': None,
            'expiration': None,
            'lifespan_class': 'LONG_LIVED',
            'lifespan': None,
            'maximum_duration': None,
            'time_to_expire': None,
            'temporary': False,
            'account_id': None,
            'aws_role_name': None,
            'managed': False,
            'role_arn': None,
            'session_token': None,
            'state': 'DEFAULT',
            'for_presigned_url': False
        }]}

AWSCredentialsTestCase = get_test_case_cls_default(coll=service.MONGODB_CREDENTIALS_COLLECTION,
                                     wstl_package=service.__package__,
                                     href='http://localhost:8080/awscredentials/',
                                     fixtures=aws_credentials_db_store,
                                     get_actions=[Action(name='heaserver-keychain-awscredentials-get-properties',
                                                             rel=['hea-context-menu', 'hea-properties']),
                                                  Action(name='heaserver-keychain-credentials-get-self',
                                                             url='http://localhost:8080/awscredentials/{id}',
                                                             rel=['self']),
                                                  Action(name='heaserver-keychain-generate-awscredentials-file',
                                                             url='http://localhost:8080/awscredentials/{id}/climanagedcredentialscreator',
                                                             rel=['hea-dynamic-clipboard', 'hea-generate-clipboard-icon', 'hea-context-menu'],
                                                             itemif='temporary'),
                                                  Action(name='heaserver-keychain-generate-awscredentials-file-managed',
                                                             url='http://localhost:8080/awscredentials/{id}/clicredentialsfile',
                                                             rel=['hea-dynamic-clipboard', 'hea-retrieve-clipboard-icon', 'hea-context-menu'],
                                                             itemif='not temporary and not for_presigned_url'),
                                                  Action(name='heaserver-keychain-update-awscredentials-file',
                                                             url='http://localhost:8080/awscredentials/{id}/expirationextender',
                                                             rel=['hea-dynamic-standard', 'hea-generate-clipboard-icon', 'hea-context-menu'],
                                                             itemif='managed and not for_presigned_url')
                                                  ],
                                     get_all_actions=[Action(name='heaserver-keychain-awscredentials-get-properties',
                                                             rel=['hea-context-menu', 'hea-properties']),
                                                      Action(name='heaserver-keychain-credentials-get-self',
                                                                 url='http://localhost:8080/awscredentials/{id}',
                                                                 rel=['self']),
                                                      Action(name='heaserver-keychain-generate-awscredentials-file',
                                                             url='http://localhost:8080/awscredentials/{id}/climanagedcredentialscreator',
                                                             rel=['hea-dynamic-clipboard', 'hea-generate-clipboard-icon', 'hea-context-menu'],
                                                             itemif='temporary'),
                                                      Action(name='heaserver-keychain-generate-awscredentials-file-managed',
                                                             url='http://localhost:8080/awscredentials/{id}/clicredentialsfile',
                                                             rel=['hea-dynamic-clipboard', 'hea-retrieve-clipboard-icon', 'hea-context-menu'],
                                                             itemif='not temporary and not for_presigned_url'),
                                                      Action(name='heaserver-keychain-update-awscredentials-file',
                                                             url='http://localhost:8080/awscredentials/{id}/expirationextender',
                                                             rel=['hea-dynamic-standard', 'hea-generate-clipboard-icon', 'hea-context-menu'],
                                                             itemif='managed and not for_presigned_url')
                                                    ]
                                     )
